@@ -3,7 +3,7 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from .base import IWorker, IWorkerGroup, IWorkerMaster, IBuilder, IFactory
+from .base import IWorker, IWorkerGroup, IWorkerMaster, IFactory
 from .worker import EmitWorker
 from .worker_group import EmitWorkerGroup
 from .worker_master import EmitWorkerMaster
