@@ -5,7 +5,7 @@
 # @Email    : 376355670@qq.com
 from multiprocessing import cpu_count
 
-from f1z1_common import is_validators
+from f1z1_common import is_validators, UnitOfTime
 
 from ..components import (
     EmitBufferQueue,
@@ -30,15 +30,19 @@ class EmitWorkerGroupFactory(IFactory):
     @classmethod
     def create(cls,
                speed: SpeedTypes, *,
-               speed_unit: SpeedUnit = None,
+               speed_unit: SpeedUnit = UnitOfTime.MICROSECOND,
                maxsize: Size = None) -> EmitWorkerGroup:
-        speed = Speed(speed, speed_unit)
+        maxsize_ = cls._maxsize(maxsize)
         return EmitWorkerGroup(
-            EmitBufferQueue(speed, maxsize),
-            EmitTaskQueue(maxsize),
+            EmitBufferQueue(Speed(speed, speed_unit), maxsize_),
+            EmitTaskQueue(maxsize_),
             EmitRecorderChain()
         )
 
+    @classmethod
+    def _maxsize(cls, maxsize: Size = None):
+        return 2 ** 31 if is_validators.is_none(maxsize) else abs(maxsize)
+
 
 class EmitWorkerMasterFactory(IFactory):
     """
@@ -47,14 +51,14 @@ class EmitWorkerMasterFactory(IFactory):
 
     @classmethod
     def create(cls, maxsize: Size = None) -> EmitWorkerMaster:
-        maxsize = cls._get_maxsize_with_cpu(maxsize)
+        maxsize_ = cls._maxsize_with_cpu(maxsize)
         return EmitWorkerMaster(
-            EmitTaskSet(maxsize),
+            EmitTaskSet(maxsize_),
             EmitRecorderChain()
         )
 
     @classmethod
-    def _get_maxsize_with_cpu(cls, cpu: Size = None):
+    def _maxsize_with_cpu(cls, cpu: Size = None):
         min_cpu = cpu_count()
         if not is_validators.is_int(cpu):
             return min_cpu
